@@ -1,3 +1,5 @@
+import datetime
+
 from authorizenet import apicontractsv1, apicontrollers
 from django import forms
 
@@ -5,6 +7,21 @@ from .auth import get_merchant_auth
 from .controllers import AuthorizenetControllerExecutor
 
 
+def get_days_between(start_date: datetime.date, end_date: datetime.date) -> int:
+    """
+    Returns the total number of days between two dates.
+
+    :param start_date: Start date.
+    :type start_date: :py:obj:`~datetime.date`
+    :param end_date: End date.
+    :type end_date: :py:obj:`~datetime.date`
+    :returns: The number of days between the dates as an integer.
+    :rtype: :py:obj:`int`
+
+    """
+    return (end_date - start_date).days
+
+
 def get_payment_profile_transactions(
     customer_profile_id: int | str,
     payment_profile_id: int | str,
@@ -124,6 +141,18 @@ def generate_customer_address(form: forms.Form) -> apicontractsv1.customerAddres
     """
     Takes a form and returns a :py:obj:`~authorizenet.apicontractsv1.customerAddressType`.
 
+    Required form fields:
+
+    +----------------+------------------------------------------------------------+
+    | name           | type                                                       |
+    +================+============================================================+
+    | ``address``    | :py:obj:`~authorizenet.apicontractsv1.customerAddressType` |
+    +----------------+------------------------------------------------------------+
+    | ``first_name`` | :py:obj:`str`                                              |
+    +----------------+------------------------------------------------------------+
+    | ``last_name``  | :py:obj:`str`                                              |
+    +----------------+------------------------------------------------------------+
+
     :param form: A Django form.
     :type form: :py:obj:`~django.forms.Form`
     :raises ValueError: If ``address`` wasn't in the form.
@@ -152,6 +181,14 @@ def generate_customer_payment(form: forms.Form) -> apicontractsv1.paymentType:
     """
     Takes a form and returns a :py:obj:`~authorizenet.apicontractsv1.paymentType`.
 
+    Required form fields:
+
+    +-----------------+-------------------------------------------------------+
+    | name            | type                                                  |
+    +=================+=======================================================+
+    | ``credit_card`` | :py:obj:`~authorizenet.apicontractsv1.creditCardType` |
+    +-----------------+-------------------------------------------------------+
+
     :param form: A Django form.
     :type form: :py:obj:`~django.forms.Form`
     :raises ValueError: If ``credit_card`` wasn't in the form.
